#!/bin/sh
# bin-tc.sh : test case for /bin directory

tet_startup="startup"			# startup function
tet_cleanup="cleanup"			# cleanup function
iclist="ic1 ic2 ic3 ic4 ic5 ic6 ic7 ic8 ic9 ic10 ic11 ic12 ic13 ic14 ic15 ic16"
ic1="tp1"
ic2="tp2"
ic3="tp3"
ic4="tp4"
ic5="tp5"
ic6="tp6"
ic7="tp7"
ic8="tp8"
ic9="tp9"
ic10="tp10"
ic11="tp11"
ic12="tp12"
ic13="tp13"
ic14="tp14"
ic15="tp15"
ic16="tp16"


tp1()
{
	tpstart "Reference 3.10-1(A)"
	tet_infoline "The /sbin directory exists and is searchable"
	lsb_test_dir_searchable /sbin >out.stdout  2>out.stderr
	check_exit_value $? 0		# should be zero
	check_nostdout			# should be no stdout
	check_nostderr			# should be no stderr
	tpresult			# set result code
}



tp2() 
{
	tpstart "Reference 3.10-2 (A)"
	tet_infoline "The implementation provides an exec-able version of the clock"
	tet_infoline "utility in the /sbin directory. "
	lsb_test_exec /sbin/clock >out.stdout 2>out.stderr 
	check_exit_value $? 0
	check_stdout			# should be stdout
	check_nostderr			# should be no stderr
	tpresult			# set result code
}


tp3() 
{
	tpstart "Reference 3.10-3 (A)"
	tet_infoline "The implementation provides an exec-able version of the getty"
	tet_infoline "utility in the /sbin directory. "

	if ! test -x /sbin/getty
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp4() 
{
	tpstart "Reference 3.10-4 (A)"
	tet_infoline "The implementation provides an exec-able version of the init"
	tet_infoline "utility in the /sbin directory. "

	if ! test -x /sbin/init
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp5() 
{
	tpstart "Reference 3.10-5 (A)"
	tet_infoline "The implementation provides an exec-able version of the update"
	tet_infoline "utility in the /sbin directory. "

	# when /sbin/update is not called by superuser, its calls
	# flush() and sync()
	lsb_test_exec /sbin/update >out.stdout 2>out.stderr 
	check_exit_value $? 0
	check_nostdout			# should be no stdout
	check_stderr			# should be stderr
	tpresult			# set result code
}


tp6() 
{
	tpstart "Reference 3.10-6 (A)"
	tet_infoline "The implementation provides an exec-able version of the mkswap"
	tet_infoline "utility in the /sbin directory. "

	if ! test -x /sbin/mkswap
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp7() 
{
	tpstart "Reference 3.10-7 (A)"
	tet_infoline "The implementation provides an exec-able version of the swapon"
	tet_infoline "utility in the /sbin directory. "
	# call with -V for version
	lsb_test_exec /sbin/swapon -V >out.stdout 2>out.stderr 
	check_exit_value $? 0		
	check_stdout			# should be stdout
	check_nostderr			# should be stderr
	tpresult			# set result code
}


tp8() 
{
	tpstart "Reference 3.10-8 (A)"
	tet_infoline "The implementation provides an exec-able version of the swapoff"
	tet_infoline "utility in the /sbin directory. "
	if ! test -x /sbin/swapoff
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp9() 
{
	tpstart "Reference 3.10-9 (A)"
	tet_infoline "The implementation provides an exec-able version of the telinit"
	tet_infoline "utility in the /sbin directory. "
	if ! test -x /sbin/telinit
	then
		FAIL=Y
		tpresult
		return
	fi
	lsb_test_exec /sbin/telinit >out.stdout 2>out.stderr 
	check_exit_value $? 1
	check_nostdout			# should be no stdout
	check_stderr			# should be stderr
	tpresult			# set result code
}


tp10() 
{
	tpstart "Reference 3.10-10 (A)"
	tet_infoline "The implementation provides an exec-able version of the shutdown"
	tet_infoline "utility in the /sbin directory. "

	if ! test -x /sbin/shutdown
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp11() 
{
	tpstart "Reference 3.10-11 (A)"
	tet_infoline "The implementation provides an exec-able version of the fdisk"
	tet_infoline "utility in the /sbin directory. "
	if ! test -x /sbin/fdisk
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp12() 
{
	tpstart "Reference 3.10-12 (A)"
	tet_infoline "The implementation provides an exec-able version of the fsck"
	tet_infoline "utility in the /sbin directory. "
	if ! test -x /sbin/fsck
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp13() 
{
	tpstart "Reference 3.10-13 (A)"
	tet_infoline "The implementation provides an exec-able version of the mkfs"
	tet_infoline "utility in the /sbin directory. "
	if ! test -x /sbin/mkfs
	then
		FAIL=Y
	fi
	tpresult			# set result code
}


tp14() 
{
	tpstart "Reference 3.10-14 (A)"
	tet_infoline "The implementation provides an exec-able version of the mkfs.*"
	tet_infoline "utility in the /sbin directory. "
	tet_infoline "Where * is one or more of ext, ext2, minix, msdos, xia and or others unspecified. "
	for tfile in /sbin/mkfs.*
	do
		tet_infoline "Testing: $tfile"
		if ! test -x $tfile
		then
			FAIL=Y
		fi
	done
	tpresult			# set result code
}


tp15() 
{
	tpstart "Reference 3.10-15 (A)"
	tet_infoline "The implementation provides an exec-able version of the ifconfig"
	tet_infoline "utility in the /sbin directory. "
	lsb_test_exec /sbin/ifconfig >out.stdout 2>out.stderr 
	check_exit_value $? 0
	check_stdout lo			# should lo in stdout
	check_nostderr			# should be no stderr
	tpresult			# set result code
}


tp16() 
{
	tpstart "Reference 3.10-16 (A)"
	tet_infoline "The implementation provides an exec-able version of the route"
	tet_infoline "utility in the /sbin directory. "
	lsb_test_exec /sbin/route >out.stdout 2>out.stderr 
	check_exit_value $? 0
	check_stdout 127.0.0.0		# should be 127.0.0.0 in stdout
	check_nostderr			# should be no stderr
	tpresult			# set result code
}


startup() # startup function
{
     rm -f out.stdout out.stderr out.experr >/dev/null 2>&1
}


cleanup() # clean-up function
{
     rm -f out.stdout out.stderr out.experr >/dev/null 2>&1
}

# source common shell functions

. $TET_EXECUTE/LIB/shfuncs.sh
. $TET_EXECUTE/LIB/lsbfuncs.sh

# execute shell test case manager - must be last line
. $TET_ROOT/lib/xpg3sh/tcm.sh
